@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of notes in a scale
 
-our $VERSION = '0.0103';
+our $VERSION = '0.02';
 
 use Carp;
 use Moo;
@@ -27,6 +27,12 @@ has scale_name => (
 );
 
 
+has verbose => (
+    is      => 'ro',
+    default => sub { 0 },
+);
+
+
 sub get_offset {
     my ( $self, %args ) = @_;
 
@@ -36,10 +42,13 @@ sub get_offset {
     my $rev;  # Going in reverse?
 
     my $note = Music::Note->new( $args{note_name}, $args{note_format} );
-#warn(__PACKAGE__,' L',__LINE__,". MARK: $args{note_name} - ",$note->format('ISO'),"\n");
+    warn sprintf "Given note: %s, ISO: %s\n", $args{note_name}, $note->format('ISO')
+        if $self->verbose;
 
     my @scale = get_scale_notes( $self->scale_note, $self->scale_name );
-#warn(__PACKAGE__,' L',__LINE__,". MARK: @scale",,"\n");
+    warn "\tScale: @scale\n"
+        if $self->verbose;
+
     if ( $args{offset} < 0 ) {
         $rev++;
         $args{offset} = abs $args{offset};
@@ -47,9 +56,11 @@ sub get_offset {
     }
 
     my $posn = first { $scale[$_] eq $note->format('isobase') } 0 .. $#scale;
-#warn(__PACKAGE__,' L',__LINE__,". MARK: $args{note_name}=$posn\n") if $posn;
-
-    $args{offset} += $posn if $posn;
+    if ( $posn ) {
+        warn sprintf "\tPosition: %d\n", $posn
+            if $self->verbose;
+        $args{offset} += $posn;
+    }
 
     my $octave = $note->octave;
     my $factor = int( $args{offset} / @scale );
@@ -60,9 +71,13 @@ sub get_offset {
     else {
         $octave += $factor;
     }
+    croak "Octave: $octave out of bounds"
+        if $octave < 0 or $octave > 127;
 
     $note = Music::Note->new( $scale[ $args{offset} % @scale ] . $octave, 'ISO' );
-#warn(__PACKAGE__,' L',__LINE__,". MARK: $args{offset} => ",$note->format('ISO') .' - '.$note->format($args{note_format}),"\n");
+    warn sprintf "\tOffset: %d, ISO: %s, Formatted: %s\n",
+        $args{offset}, $note->format('ISO'), $note->format($args{note_format})
+        if $self->verbose;
 
     return $note;
 }
@@ -81,7 +96,7 @@ Music::ScaleNote - Manipulate the position of notes in a scale
 
 =head1 VERSION
 
-version 0.0103
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -115,6 +130,10 @@ See L<Music::Scales/SCALES> for the possible names.
 
 Default: major
 
+=head2 verbose
+
+Show the progress of the B<get_offset> method.
+
 =head1 METHODS
 
 =head2 new()
